#!/bin/sh

svn_host=svn://svn.mplayerhq.hu
mplayer_rev=32819
ffmpeg_rev=26402
dvdnav_rev=1219
dir=mplayer-vaapi
last_step=build
enable_vaapi="--enable-vaapi"
enable_vdpau="--disable-vdpau"

if [ $# -gt 0 ]; then
    arg="$1"
    case $arg in
	extract|prepare|configure|build|checkout|patch)
	    last_step=$arg
	    shift
	    ;;
    esac
fi

case $last_step in
    checkout)
	last_step=extract
	;;
    patch)
	last_step=prepare
	;;
esac

ncpus=`getconf _NPROCESSORS_ONLN`
if [ $ncpus -gt 1 ]; then
    ncpus=`expr $ncpus + $ncpus / 2`
fi
DEFAULT_NCPUS=$ncpus

ncpus=${BUILD_NCPUS:-${DEFAULT_NCPUS}}
if [ $ncpus -lt 1 ]; then
    ncpus=1
fi

if ! [ -f /usr/include/va/va.h ]; then
    echo "ERROR: you need VA API headers for this project" > /dev/stderr
    exit 1
fi

get_svn_revision() {
    LC_ALL=C svn info $1 | sed -n 's/Revision: \([0-9]*\)/\1/p' 2>/dev/null
}

update_svn_tree() {
    local rev="$1"
    shift 1
    for dir in ${1+"$@"}; do
	if [ `get_svn_revision $dir` -ne $rev ]; then
	    echo "Updating $dir"
	    svn update --ignore-externals -r $rev $dir >/dev/null
	fi
    done
}

ffmpeg_externs="ffmpeg"
dvdnav_externs="libdvdread4 libdvdnav"
if test -d "$dir"; then
    cd $dir
    has_local_changes=0
    for d in "" $ffmpeg_externs $dvdnav_externs; do
	if svn status --ignore-externals|grep -vq ^X; then
	    has_local_changes=1
	fi
    done
    if [ $has_local_changes != 0 ]; then
	echo "ERROR: $dir/ already exists and has local changes, please remove it first" > /dev/stderr
	exit 1
    fi

    update_svn_tree $mplayer_rev .
    update_svn_tree $ffmpeg_rev $ffmpeg_externs
    update_svn_tree $dvdnav_rev $dvdnav_externs
else
    svn co --ignore-externals -r $mplayer_rev $svn_host/mplayer/trunk $dir
    cd $dir
    svn co -r $ffmpeg_rev $svn_host/ffmpeg/trunk ffmpeg
    svn co -r $dvdnav_rev $svn_host/dvdnav/trunk/libdvdread/src libdvdread4
    svn co -r $dvdnav_rev $svn_host/dvdnav/trunk/libdvdnav/src libdvdnav
fi

if [ "$last_step" = "extract" ]; then
    exit 0
fi

patch -p1 < ../patches/mplayer-vaapi.patch			|| exit 1
patch -p1 < ../patches/mplayer-vaapi-gma500-workaround.patch	|| exit 1
patch -p1 < ../patches/mplayer-vaapi-0.29.patch			|| exit 1
patch -p1 < ../patches/mplayer-vdpau.patch			|| exit 1

if [ "$last_step" = "prepare" ]; then
    exit 0
fi

./configure $enable_vaapi $enable_vdpau ${1+"$@"}

if [ "$last_step" = "configure" ]; then
    exit 0
fi

make -j$ncpus

if [ "$last_step" = "build" ]; then
    exit 0
fi

exit 0
